==> fantacalciobazar_0.5.2.tar.gz: fantacalciobazar/scambio_accetta.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



$lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
flock($lock,2);
$lock2 = fopen("$percorso_cartella_dati/scambi.lock","w+");
flock($lock2,2);

$trovato = "NO";
$num_calciatori_posseduti = 0;
$num_calciatori_effettivi = 0;
$soldi_spesi = 0;
$calciatori_utente = "";
$num_calciatori_posseduti_altro = 0;
$num_calciatori_effettivi_altro = 0;
$soldi_spesi_altro = 0;
$calciatori_altro = "";
$calciatori_offerti = "";
$calciatori_richiesti = "";
$num_calciatori_offerti = 0;
$num_calciatori_richiesti = 0;
$lista_off = "";
$lista_ric = "";
$ini_lista_off = "";
$ini_lista_ric = "";

$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);

for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
if ($id_scambio == $dati_scambio[0]) {
$trovato = "SI";
$utente_offerente = $dati_scambio[1];
$calciatori_offerti = $dati_scambio[2];
$calciatori_offerti = explode(";", $calciatori_offerti);
$num_calciatori_offerti = count($calciatori_offerti);
$soldi_offerti = $dati_scambio[3];
$utente_richiesto = $dati_scambio[4];
if ($utente_richiesto != $nome_utente) $trovato = "NO";
$calciatori_richiesti = $dati_scambio[5];
$calciatori_richiesti = explode(";", $calciatori_richiesti);
$num_calciatori_richiesti = count($calciatori_richiesti);
$soldi_richiesti = $dati_scambio[6];
$tempo_off = $dati_scambio[7];
$tempo_off = togli_acapo($tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) $trovato = "NO";
break;
} # fine if ($id_scambio == $dati_scambio[0])
} # fine for $num1

if ($trovato == "NO") echo "Proposta di scambio non trovata.<br>";

else {


if ($stato_mercato == "C") {
echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
} # fine if ($stato_mercato == "C")

else {


if (!$sicuro) {
echo "<form method=\"post\" action=\"./scambio_accetta.php\">
Sei sicuro di voler accettare lo scambio proposto da <b>$utente_offerente</b>?&nbsp;
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"id_scambio\" value=\"$id_scambio\">
<input type=\"submit\" name=\"sicuro\" value=\"SI\">
</form>";
} # fine if (!$sicuro)

else {


$lock3 = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
flock($lock3,2);
$lock4 = fopen("$percorso_cartella_dati/squadra_$utente_offerente.lock","w+");
flock($lock4,2);

$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
$proprietario = $dati_calciatore[4];

if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
if ($sec_restanti < 0) {
$num_calciatori_effettivi++;
$nomi_calciatori_utente[$num_calciatori_effettivi] = $nome;
$num_calciatori_utente[$num_calciatori_effettivi] = $numero;
$calciatori_utente[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $nome_utente)

if ($proprietario == $utente_offerente) {
$soldi_spesi_altro = $soldi_spesi_altro + $dati_calciatore[3];
$num_calciatori_posseduti_altro++;
if ($sec_restanti < 0) { 
$num_calciatori_effettivi_altro++;
$nomi_calciatori_altro[$num_calciatori_effettivi_altro] = $nome;
$num_calciatori_altro[$num_calciatori_effettivi_altro] = $numero;
$calciatori_altro[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $altro_utente)

} # fine for $num1


for ($num1 = 0 ; $num1 < $num_calciatori_richiesti ; $num1++) {
$calciatore_scambio_utente = $calciatori_richiesti[$num1];
if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and $calciatore_scambio_utente != "") {
$scambiare = "NO";
echo "Nella richiesta c' un calciatore non pi in tuo possesso.<br>";
} # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
} # fine for $num1
for ($num1 = 0 ; $num1 < $num_calciatori_offerti ; $num1++) {
$calciatore_scambio_altro = $calciatori_offerti[$num1];
if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and $calciatore_scambio_utente != "") {
$scambiare = "NO";
echo "Nell' offerta c' un calciatore non pi posseduto da $utente_offerente.<br>";
} # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
} # fine for $num1

$num_calciatori_dopo = $num_calciatori_posseduti + $num_calciatori_offerti - $num_calciatori_richiesti;
if ($num_calciatori_dopo > $max_calciatori) {
$scambiare = "NO";
echo "Dopo lo scambio avresti pi di $max_calciatori calciatori.<br>";
} # fine if ($num_calciatori_dopo > $max_calciatori)
$num_calciatori_dopo_altro = $num_calciatori_posseduti_altro + $num_calciatori_richiesti - $num_calciatori_offerti;
if ($num_calciatori_dopo_altro > $max_calciatori) {
$scambiare = "NO";
echo "Dopo lo scambio $utente_offerente avrebbe pi di $max_calciatori calciatori.<br>";
} # fine if ($num_calciatori_dopo > $max_calciatori)

$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($soldi_richiesti > $soldi_spendibili) {
$scambiare = "NO";
echo "Ti sono richiesti pi soldi di quelli da te posseduti.<br>";
} # fine if ($soldi_richiesti > $soldi_spendibili)
$surplus_altro = @file("$percorso_cartella_dati/squadra_$utente_offerente");
$surplus_altro = $surplus_altro[0];
$soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
if ($soldi_offerti > $soldi_spendibili_altro) {
$scambiare = "NO";
echo "I soldi offerti sono pi di quelli posseduti da $utente_offerente.<br>";
} # fine if ($soldi_offerti > $soldi_spendibili_altro)

# se i controlli sono andati bene effettuo lo scambio
if ($scambiare != "NO") {

$file_mercato = fopen("$percorso_cartella_dati/mercato.txt","w+");
flock($file_mercato,2);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$tempo_off = togli_acapo($tempo_off);
$scritto_linea = "NO";
for ($num2 = 0 ; $num2 < $num_calciatori_richiesti ; $num2++) {
if ($numero == $calciatori_richiesti[$num2]) {
$linea = "$numero,$nome,$ruolo,$costo,$utente_offerente,$tempo_off";
fwrite($file_mercato,"$linea
");
$costo_calciatori_richiesti = $costo_calciatori_richiesti + $costo;
$scritto_linea = "SI";
if ($ini_lista_ric) $lista_ric .= " + $nome";
else $lista_ric = "$nome";
$ini_lista_ric = "SI";
} # fine if ($numero = $calciatori_richiesti[$num2])
} # fine for $num2
for ($num2 = 0 ; $num2 < $num_calciatori_offerti ; $num2++) {
if ($numero == $calciatori_offerti[$num2]) {
$linea = "$numero,$nome,$ruolo,$costo,$nome_utente,$tempo_off";
fwrite($file_mercato,"$linea
");
$costo_calciatori_offerti = $costo_calciatori_offerti + $costo;
$scritto_linea = "SI";
if ($ini_lista_off) $lista_off .= " + $nome";
else $lista_off = "$nome";
$ini_lista_off = "SI";
} # fine if ($numero = $calciatori_offerti[$num2])
} # fine for $num2
if ($scritto_linea == "NO") {
fwrite($file_mercato,$calciatori[$num1]);
} # fine if ($scritto_linea == "NO")
} # fine for $num1
flock($file_mercato,3);
fclose($file_mercato);

$aggiungi_surplus = $costo_calciatori_offerti - $costo_calciatori_richiesti + $soldi_offerti - $soldi_richiesti;
$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,$linee[$num1]);
} # fine for $num1
flock($filesquadra,3);
fclose($filesquadra);

$aggiungi_surplus = $costo_calciatori_richiesti - $costo_calciatori_offerti + $soldi_richiesti - $soldi_offerti;
$linee = @file("$percorso_cartella_dati/squadra_$utente_offerente");
$filesquadra = fopen("$percorso_cartella_dati/squadra_$utente_offerente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,$linee[$num1]);
} # fine for $num1
flock($filesquadra,3);
fclose($filesquadra);

$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);
$file_scambi = fopen("$percorso_cartella_dati/scambi.txt","w+");
flock($file_scambi,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
# se lo scambio  scaduto non lo riscrivo
$dati_scambio = explode(",", $scambi_proposti[$num1]);
$tempo_off = $dati_scambio[7];
$tempo_off = togli_acapo($tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti > 0 and $id_scambio != $dati_scambio[0]) fwrite($file_scambi,$scambi_proposti[$num1]);
} # fine for $num1
flock($file_scambi,3);
fclose($file_scambi);

if ($soldi_richiesti != 0) $lista_ric .= " + $soldi_richiesti Euro";
if ($soldi_offerti != 0) $lista_off .= " + $soldi_offerti Euro";
$nuovo_messaggio = "$nome_utente ha accettato lo scambio proposto da $utente_offerente per $lista_ric in cambio di $lista_off";
$file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
flock($file_messaggi,2);
fwrite($file_messaggi,"Radio mercato#@?".date("d/m H:i")."#@?".$nuovo_messaggio."
");
flock($file_messaggi,3);
fclose($file_messaggi);
echo "Lo scambio  stato effettuato!<br>";
} # fine if ($scambiare != "NO")

if ($scambiare == "NO") echo "Scambio non permesso.<br>";

flock($lock4,3);
fclose($lock4);
flock($lock3,3);
fclose($lock3);


} # fine else if (!$sicuro)

} # fine else if ($stato_mercato == "C")

} # fine else if ($trovato == "NO")


flock($lock2,3);
fclose($lock2);
flock($lock,3);
fclose($lock);

echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.3.tar.gz: fantacalciobazar/scambio_accetta.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



$lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
flock($lock,2);
$lock2 = fopen("$percorso_cartella_dati/scambi.lock","w+");
flock($lock2,2);

$trovato = "NO";
$num_calciatori_posseduti = 0;
$num_calciatori_effettivi = 0;
$soldi_spesi = 0;
$calciatori_utente = "";
$num_calciatori_posseduti_altro = 0;
$num_calciatori_effettivi_altro = 0;
$soldi_spesi_altro = 0;
$calciatori_altro = "";
$calciatori_offerti = "";
$calciatori_richiesti = "";
$num_calciatori_offerti = 0;
$num_calciatori_richiesti = 0;
$lista_off = "";
$lista_ric = "";
$ini_lista_off = "";
$ini_lista_ric = "";

$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);

for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
if ($id_scambio == $dati_scambio[0]) {
$trovato = "SI";
$utente_offerente = $dati_scambio[1];
$calciatori_offerti = $dati_scambio[2];
$calciatori_offerti = explode(";", $calciatori_offerti);
$num_calciatori_offerti = count($calciatori_offerti);
$soldi_offerti = $dati_scambio[3];
$utente_richiesto = $dati_scambio[4];
if ($utente_richiesto != $nome_utente) $trovato = "NO";
$calciatori_richiesti = $dati_scambio[5];
$calciatori_richiesti = explode(";", $calciatori_richiesti);
$num_calciatori_richiesti = count($calciatori_richiesti);
$soldi_richiesti = $dati_scambio[6];
$tempo_off = $dati_scambio[7];
$tempo_off = togli_acapo($tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) $trovato = "NO";
break;
} # fine if ($id_scambio == $dati_scambio[0])
} # fine for $num1

if ($trovato == "NO") echo "Proposta di scambio non trovata.<br>";

else {


if ($stato_mercato == "C") {
echo "<center>Il mercato è <b>chiuso</b> in questo momento.</center><br>";
} # fine if ($stato_mercato == "C")

else {


if (!$sicuro) {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"./scambio_accetta.php\">
Sei sicuro di voler accettare lo scambio proposto da <b>$utente_offerente</b>?&nbsp;
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"id_scambio\" value=\"$id_scambio\">
<input type=\"submit\" name=\"sicuro\" value=\"SI\">
</form>";
} # fine if (!$sicuro)

else {


$lock3 = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
flock($lock3,2);
$lock4 = fopen("$percorso_cartella_dati/squadra_$utente_offerente.lock","w+");
flock($lock4,2);

$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
$proprietario = $dati_calciatore[4];

if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
if ($sec_restanti < 0) {
$num_calciatori_effettivi++;
$nomi_calciatori_utente[$num_calciatori_effettivi] = $nome;
$num_calciatori_utente[$num_calciatori_effettivi] = $numero;
$calciatori_utente[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $nome_utente)

if ($proprietario == $utente_offerente) {
$soldi_spesi_altro = $soldi_spesi_altro + $dati_calciatore[3];
$num_calciatori_posseduti_altro++;
if ($sec_restanti < 0) { 
$num_calciatori_effettivi_altro++;
$nomi_calciatori_altro[$num_calciatori_effettivi_altro] = $nome;
$num_calciatori_altro[$num_calciatori_effettivi_altro] = $numero;
$calciatori_altro[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $altro_utente)

} # fine for $num1


for ($num1 = 0 ; $num1 < $num_calciatori_richiesti ; $num1++) {
$calciatore_scambio_utente = $calciatori_richiesti[$num1];
if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and $calciatore_scambio_utente != "") {
$scambiare = "NO";
echo "Nella richiesta c'è un calciatore non più in tuo possesso.<br>";
} # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
} # fine for $num1
for ($num1 = 0 ; $num1 < $num_calciatori_offerti ; $num1++) {
$calciatore_scambio_altro = $calciatori_offerti[$num1];
if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and $calciatore_scambio_utente != "") {
$scambiare = "NO";
echo "Nell' offerta c'è un calciatore non più posseduto da $utente_offerente.<br>";
} # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
} # fine for $num1

$num_calciatori_dopo = $num_calciatori_posseduti + $num_calciatori_offerti - $num_calciatori_richiesti;
if ($num_calciatori_dopo > $max_calciatori) {
$scambiare = "NO";
echo "Dopo lo scambio avresti più di $max_calciatori calciatori.<br>";
} # fine if ($num_calciatori_dopo > $max_calciatori)
$num_calciatori_dopo_altro = $num_calciatori_posseduti_altro + $num_calciatori_richiesti - $num_calciatori_offerti;
if ($num_calciatori_dopo_altro > $max_calciatori) {
$scambiare = "NO";
echo "Dopo lo scambio $utente_offerente avrebbe più di $max_calciatori calciatori.<br>";
} # fine if ($num_calciatori_dopo > $max_calciatori)

$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($soldi_richiesti > $soldi_spendibili) {
$scambiare = "NO";
echo "Ti sono richiesti più soldi di quelli da te posseduti.<br>";
} # fine if ($soldi_richiesti > $soldi_spendibili)
$surplus_altro = @file("$percorso_cartella_dati/squadra_$utente_offerente");
$surplus_altro = $surplus_altro[0];
$soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
if ($soldi_offerti > $soldi_spendibili_altro) {
$scambiare = "NO";
echo "I soldi offerti sono più di quelli posseduti da $utente_offerente.<br>";
} # fine if ($soldi_offerti > $soldi_spendibili_altro)

# se i controlli sono andati bene effettuo lo scambio
if ($scambiare != "NO") {

$file_mercato = fopen("$percorso_cartella_dati/mercato.txt","w+");
flock($file_mercato,2);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$tempo_off = togli_acapo($tempo_off);
$scritto_linea = "NO";
for ($num2 = 0 ; $num2 < $num_calciatori_richiesti ; $num2++) {
if ($numero == $calciatori_richiesti[$num2]) {
$linea = "$numero,$nome,$ruolo,$costo,$utente_offerente,$tempo_off";
fwrite($file_mercato,"$linea
");
$costo_calciatori_richiesti = $costo_calciatori_richiesti + $costo;
$scritto_linea = "SI";
if ($ini_lista_ric) $lista_ric .= " + $nome";
else $lista_ric = "$nome";
$ini_lista_ric = "SI";
} # fine if ($numero = $calciatori_richiesti[$num2])
} # fine for $num2
for ($num2 = 0 ; $num2 < $num_calciatori_offerti ; $num2++) {
if ($numero == $calciatori_offerti[$num2]) {
$linea = "$numero,$nome,$ruolo,$costo,$nome_utente,$tempo_off";
fwrite($file_mercato,"$linea
");
$costo_calciatori_offerti = $costo_calciatori_offerti + $costo;
$scritto_linea = "SI";
if ($ini_lista_off) $lista_off .= " + $nome";
else $lista_off = "$nome";
$ini_lista_off = "SI";
} # fine if ($numero = $calciatori_offerti[$num2])
} # fine for $num2
if ($scritto_linea == "NO") {
fwrite($file_mercato,$calciatori[$num1]);
} # fine if ($scritto_linea == "NO")
} # fine for $num1
flock($file_mercato,3);
fclose($file_mercato);

$aggiungi_surplus = $costo_calciatori_offerti - $costo_calciatori_richiesti + $soldi_offerti - $soldi_richiesti;
$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,$linee[$num1]);
} # fine for $num1
flock($filesquadra,3);
fclose($filesquadra);

$aggiungi_surplus = $costo_calciatori_richiesti - $costo_calciatori_offerti + $soldi_richiesti - $soldi_offerti;
$linee = @file("$percorso_cartella_dati/squadra_$utente_offerente");
$filesquadra = fopen("$percorso_cartella_dati/squadra_$utente_offerente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,$linee[$num1]);
} # fine for $num1
flock($filesquadra,3);
fclose($filesquadra);

$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);
$file_scambi = fopen("$percorso_cartella_dati/scambi.txt","w+");
flock($file_scambi,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
# se lo scambio è scaduto non lo riscrivo
$dati_scambio = explode(",", $scambi_proposti[$num1]);
$tempo_off = $dati_scambio[7];
$tempo_off = togli_acapo($tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti > 0 and $id_scambio != $dati_scambio[0]) fwrite($file_scambi,$scambi_proposti[$num1]);
} # fine for $num1
flock($file_scambi,3);
fclose($file_scambi);

if ($soldi_richiesti != 0) $lista_ric .= " + $soldi_richiesti Euro";
if ($soldi_offerti != 0) $lista_off .= " + $soldi_offerti Euro";
$nuovo_messaggio = "$nome_utente ha accettato lo scambio proposto da $utente_offerente per $lista_ric in cambio di $lista_off";
$file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
flock($file_messaggi,2);
fwrite($file_messaggi,"Radio mercato#@?".date("d/m H:i")."#@?".$nuovo_messaggio."
");
flock($file_messaggi,3);
fclose($file_messaggi);
echo "Lo scambio è stato effettuato!<br>";
} # fine if ($scambiare != "NO")

if ($scambiare == "NO") echo "Scambio non permesso.<br>";

flock($lock4,3);
fclose($lock4);
flock($lock3,3);
fclose($lock3);


} # fine else if (!$sicuro)

} # fine else if ($stato_mercato == "C")

} # fine else if ($trovato == "NO")


flock($lock2,3);
fclose($lock2);
flock($lock,3);
fclose($lock);

echo "<br><br><center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
